/*
	The DIY Prime Wake Up Light
	electronics.nilshugo.se
	
	Copyright 2012 Christian Larsson 
	electronics@nilshugo.se
*/

#include <avr/io.h>
#include "dispControl.h"

volatile unsigned char dotStatus;

void selectDisp(unsigned char disp){
	unsigned char dotLight;
	
	DISP_AND_RELAY_CTRL_PORT |= 0b00001111;
	
	switch(disp){
		case 0:
			DISP_AND_RELAY_CTRL_PORT &= 0b11111110;
			break;
		case 1:
			DISP_AND_RELAY_CTRL_PORT &= 0b11111101;
			break;
		case 2:
			DISP_AND_RELAY_CTRL_PORT &= 0b11111011;
			break;
		case 3:
			DISP_AND_RELAY_CTRL_PORT &= 0b11110111;
			break;
	}
	
	dotLight = ~(dotStatus << (7-disp));
	dotLight |= 0b01111111;
	
	DISP_PORT = dotLight;
	
	return;
}

void printNr(unsigned char nr){
	unsigned char LEDCombination;

	switch(nr){
		case 0:
			LEDCombination = 0b10010000;
			break;
		case 1:
			LEDCombination = 0b11010111;
			break;
		case 2:
			LEDCombination = 0b10100010;
			break;
		case 3:
			LEDCombination = 0b10000110;
			break;
		case 4:
			LEDCombination = 0b11000101;
			break;
		case 5:
			LEDCombination = 0b10001100;
			break;
		case 6:
			LEDCombination = 0b10001000;
			break;
		case 7:
			LEDCombination = 0b11010110;
			break;
		case 8:
			LEDCombination = 0b10000000;
			break;
		case 9:
			LEDCombination = 0b11000100;
			break;
		default:
			LEDCombination = 0xFF;
			break;
	}
	
	DISP_PORT &= LEDCombination;
	
	return;
}

void shutOffDisp(void){
	DISP_PORT = 0xFF;
	return;
}

void controlDot(unsigned char dot3, unsigned char dot2, unsigned char dot1, unsigned char dot0){
	dotStatus = 0x00 | (dot3 << 3);
	dotStatus |= (dot2 << 2);
	dotStatus |= (dot1 << 1);
	dotStatus |= dot0;
	
	return;
}

void controlDisplayContentThreeDigits(volatile unsigned char* displayContentArray, unsigned long int numberToDisplay){
	displayContentArray[0] = (numberToDisplay)%10;
	displayContentArray[1] = (numberToDisplay/10)%10;
	displayContentArray[2] = (numberToDisplay/100)%10;
	displayContentArray[3] = -1;
	
	return;
}

void controlDisplayContentTime(char blinkPosition, char blinkPositionOnOrOff, volatile unsigned char* displayContentArray, unsigned char firstDigits, unsigned char secondDigits){
	controlDot(0, 1, 0, 0);

	if(blinkPosition != BLINK_NONE && blinkPositionOnOrOff == BLINK_OFF){
		if(blinkPosition == BLINK_FIRST){
			displayContentArray[3] = -1;
			displayContentArray[2] = -1;
			displayContentArray[1] = secondDigits/10;
			displayContentArray[0] = secondDigits%10;			
		}
		else{
			displayContentArray[3] = firstDigits/10;
			displayContentArray[2] = firstDigits%10;
			displayContentArray[1] = -1;
			displayContentArray[0] = -1;
		}
	}
	else{
		displayContentArray[3] = firstDigits/10;
		displayContentArray[2] = firstDigits%10;
		displayContentArray[1] = secondDigits/10;
		displayContentArray[0] = secondDigits%10;		
	}		 

	return;
}